@@ -11,6 +11,7 @@
 #include <QLoggingCategory>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
+#include <QSessionManager>
 #include <QWindow>
 
 #include <KAboutData>
@@ -62,6 +63,32 @@ private:
     QString m_pageName;
 };
 
+class SessionManager : public QObject
+{
+    Q_OBJECT
+public:
+    SessionManager(QObject *parent);
+
+private:
+    QString m_pageId;
+};
+
+SessionManager::SessionManager(QObject *parent)
+    : QObject(parent)
+{
+    connect(qApp, &QGuiApplication::saveStateRequest, this, [this](QSessionManager &manager) {
+        QString lastPageId = Configuration::globalConfig()->lastPage();
+        if (lastPageId.isEmpty()) {
+            return;
+        }
+        QStringList args;
+        args << qApp->applicationName();
+        args << QStringLiteral("--page-id") << lastPageId;
+        args << QStringLiteral("-session") << manager.sessionId();
+        manager.setRestartCommand(args);
+    });
+}
+
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
@@ -84,12 +111,12 @@ int main(int argc, char **argv)
     aboutData.setProgramLogo(app.windowIcon());
 
     aboutData.addAuthor(i18n("Arjen Hiemstra"), i18n("Development"), QStringLiteral("ahiemstra@heimr.nl"));
-    aboutData.addAuthor(i18n("Uri Herrera"), i18n("Design"), QString{});
-    aboutData.addAuthor(i18n("Nate Graham"), i18n("Design and Quality Assurance"), QString{});
-    aboutData.addAuthor(i18n("David Redondo"), i18n("Development"), QString{});
-    aboutData.addAuthor(i18n("Noah Davis"), i18n("Design and Quality Assurance"), QString{});
-    aboutData.addAuthor(i18n("Marco Martin"), i18n("Development"), QString{});
-    aboutData.addAuthor(i18n("David Edmundson"), i18n("Development"), QString{});
+    aboutData.addAuthor(i18n("Uri Herrera"), i18n("Design"), QStringLiteral("uri_herrera@nxos.org"));
+    aboutData.addAuthor(i18n("Nate Graham"), i18n("Design and Quality Assurance"), QStringLiteral("nate@kde.org"));
+    aboutData.addAuthor(i18n("David Redondo"), i18n("Development"), QStringLiteral("kde@david-redondo.de"));
+    aboutData.addAuthor(i18n("Noah Davis"), i18n("Design and Quality Assurance"), QStringLiteral("noahadvs@gmail.com"));
+    aboutData.addAuthor(i18n("Marco Martin"), i18n("Development"), QStringLiteral("notmart@gmail.com"));
+    aboutData.addAuthor(i18n("David Edmundson"), i18n("Development"), QStringLiteral("david@davidedmundson.co.uk"));
 
     aboutData.setTranslator(i18ndc(nullptr, "NAME OF TRANSLATORS", "Your names"), i18ndc(nullptr, "EMAIL OF TRANSLATORS", "Your emails"));
 
@@ -111,6 +138,7 @@ int main(int argc, char **argv)
     qmlRegisterSingletonType<CommandLineArguments>("org.kde.systemmonitor", 1, 0, "CommandLineArguments", [&parser](QQmlEngine *, QJSEngine *) {
         return new CommandLineArguments{parser};
     });
+    auto sessionManager = new SessionManager(&app);
 
     KQuickAddons::QtQuickSettings::init();
 
